class frequenciesOfItems:
    def __init__(self, transactional_db, separator='\t'):
        self.transactional_db = transactional_db
        self.separator = separator

    def getFrequencies(self):
        item_freq_dict = {}

        # Read the transactional database and calculate item frequencies
        with open(self.transactional_db, 'r') as f:
            for line in f:
                items = line.strip().split(self.separator)
                for item in items:
                    if item in item_freq_dict:
                        item_freq_dict[item] += 1
                    else:
                        item_freq_dict[item] = 1

        return item_freq_dict


import plotly.express as px

class heatMapItemsFrequencies:
    def __init__(self, items_frequencies):
        self.items_frequencies = items_frequencies

    def plot_heatmap(self):
        # Extract data from the items_frequencies dictionary
        lats = []
        lons = []
        freqs = []
        for item, freq in self.items_frequencies.items():
            lat, lon = item.split(',')
            lats.append(float(lat))
            lons.append(float(lon))
            freqs.append(freq)

        # Create the heatmap plot using Plotly Express
        fig = px.density_mapbox(
            lat=lats,
            lon=lons,
            z=freqs,
            radius=20,
            center=dict(lat=sum(lats) / len(lats), lon=sum(lons) / len(lons)),
            mapbox_style="open-street-map"
        )

        # Show the plot
        fig.show()


import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='s1280247_learn2',
    version='2023.07.27',
    author='Tsubasa Yamauchi',
    author_email='s1280247@u-aizu.ac.jp',
    description='This ssoftware is being developd in the Python Class, University of Aizu.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    url='https://github.com/s1280247/s1280247_learn.git',
    license='GPLv3',
    install_requires=[
        'pandas',
        'plotly',
    ],
    extras_require={
        'gpu': ['cupy', 'pycuda'],
        'spark': ['pyspark'],
        'dev': ['twine', 'setuptools', 'build'],
        'all': ['cupy', 'pycuda', 'pyspark', 'twine', 'setuptools', 'build']
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
    ],
    python_requiers='>=3.5',
)
